@@ -16,6 +16,9 @@ class StartWork(Message):
     # 各个容器收到startWork不一样， 默认返回START_WORK_SUCCESS_ACK
 
     def do_start_work(self):
+        if self.agentClient:
+            self.agentClient.biz_work_id = self.get_cmd_params()['bizWorkId']
+            logger.info("bizWorkId: %s start" % self.agentClient.biz_work_id)
         logger.info("do start work")
         return True
 
