@@ -27,7 +27,7 @@ class StartWorkFail(Message):
                 "params": {}
             }
         }
-        super(StartWorkFail, self).__init__(header, body)
+        super(StartWorkFail, self).__init__(header, body, agent_client)
 
     def process(self):
         self.agentClient.send_message(self.get_package_string())
